Enum pliantdb::server::local::backup::Command [−][src]
pub enum Command {
Save {
output_directory: Option<PathBuf>,
output_name: Option<String>,
},
Load {
backup: PathBuf,
},
}The command to execute.
Variants
Exports all of the data into a straightforward file structure.
This command will create a single folder within output_directory named
output_name. Within that folder, one subfolder will be created for
each database Database. Inside of each database
folder will be a folder of any transactions (_transactions), as well
as one folder for each collection’s CollectionName. The transactions
folder will have one file for each Executed transaction. Each
collection folder will contain files named
<Document.header.id>.<Document.header.revision.id>, and the files will
contain the raw bytes stored inside of the documents. Assuming you’re
using the built in Serialization, the data will be in the
CBOR format, otherwise it will be the bytes you
stored within the database.
This format should make it easy to migrate data as well as back it up using many traditional methods, and should be considered the official way to do a full export of a database without using the API.
Show fields
Fields of Save
output_directory: Option<PathBuf>The directory to export the data within. The process will create a
subfolder using output_name. If omitted, the export is performed
next to the source database.
output_name: Option<String>The name of the folder to export the data to. If not specified, the “.backup” is appended to the source database’s name and used.
Loads all of the data from a previously saved backup. Any documents with the same IDs will be overwritten by the documents in this backup.
Show fields
Fields of Load
backup: PathBufThe path to the previously saved backup.
Implementations