Struct pliantdb::server::local::core::circulate::flume::SendError[]

pub struct SendError<T>(pub T);

An error that may be emitted when attempting to send a value into a channel on a sender when all receivers are dropped.